// check if something needs to be done?

import './uafrica-shipping.scss';

const uAfricaShipping = class {
	/**
	 * @param {Element} containerEle
	 */
	constructor( containerEle ) {
		this.containerEle = containerEle;
		this.formEle = this.containerEle.querySelector( 'form' );
		this.submitBttn = this.formEle.querySelector( 'button' );
		this.validationEle = this.containerEle.querySelector( '.validation' );
		this.stepFormEle = this.containerEle.querySelector(
			'.shipping-step-form'
		);
		this.stepStatusEle = this.containerEle.querySelector(
			'.shipping-step-status'
		);

		this.abortController = new AbortController();

		this.getOrderNumberQueryParam();
		this.handleFormSubmit();

		// do we need to process the order on load?
		if ( '' !== this.orderNR && null !== this.orderNR ) {
			this.fetchOrderData(); // if not empty, try on page load.
		}
	}

	handleFormSubmit() {
		this.formEle.addEventListener( 'submit', ( event ) => {
			event.preventDefault();
			this.orderNR = this.formEle.querySelector(
				'input[name=order-number]'
			).value;

			if ( history.pushState ) {
				const newUrl =
					window.location.protocol +
					'//' +
					window.location.host +
					window.location.pathname +
					'?order-number=' +
					this.orderNR;
				window.history.pushState( { path: newUrl }, '', newUrl );
			}

			this.fetchOrderData();
		} );
	}

	getOrderNumberQueryParam() {
		const urlParams = new URLSearchParams( window.location.search );
		const orderNR = urlParams.get( 'order-number' );
		this.orderNR = orderNR;

		return orderNR;
	}

	fetchOrderData() {
		// Prevent double runs.
		if ( this.fetchRunning ) {
			this.abortController.abort();
			this.abortController = new AbortController();
		} else {
			this.fetchRunning = true;
		}

		this.submitBttn.disabled = true;
		this.validationEle.classList.add( 'hidden' ); // always hide the error when fetching new data.
		const url = uafrica_shipping_l10n.api_url
			.replace( 'NUMBER', this.orderNR )
			.replace( 'DOMAIN', uafrica_shipping_l10n.domain );

		fetch( url, { signal: this.abortController.signal } )
			.then( ( response ) => response.json() )
			.then( ( data ) => {
				if ( 'undefined' === typeof data[ 0 ] ) {
					this.displayError();
				} else {
					this.shipping_details = data[ 0 ];
					this.displayOrderData();
				}
			} )
			.catch( ( err ) => {
				if ( 20 !== err.code ) {
					// code 20 is an abort, which is not a problem.
					console.log( err );
					this.displayError();
				}
			} )
			.finally( () => {
				this.fetchRunning = false;
				this.submitBttn.disabled = false;
			} );
	}

	displayOrderData() {
		this.stepFormEle.classList.add( 'hidden' );
		this.stepStatusEle.classList.remove( 'hidden' );

		const classThis = this; // allow this class to be called in other functions.

		// set flat data.
		this._setValue(
			this.stepStatusEle,
			'status',
			this.shipping_details.status_friendly
		);
		this._setValue(
			this.stepStatusEle,
			'custom_order_name',
			this.shipping_details.custom_order_name
		);
		this._setValue(
			this.stepStatusEle,
			'courier_name',
			this.shipping_details.courier_name
		);
		this._setValue(
			this.stepStatusEle,
			'courier_phone',
			this.shipping_details.courier_phone
		);
		this._setValue( this.stepStatusEle, 'id', this.shipping_details.id );

		const checkpointTemplate = this.stepStatusEle.querySelector(
			'[data-uafrica=checkpoints-template] .step'
		);
		const checkpointsEle = this.stepStatusEle.querySelector(
			'.checkpoints'
		);

		// checkpoints.
		this.shipping_details.checkpoints.forEach( function ( checkpoint ) {
			const checkpointShadowEle = checkpointTemplate.cloneNode( true );

			// set icon if needed.
			if (
				'delivered' === checkpoint.status ||
				'out-for-delivery' === checkpoint.status
			) {
				checkpointShadowEle
					.querySelector( '[data-uafrica=icon] .empty' )
					.classList.add( 'hidden' );
				const activeEle = checkpointShadowEle.querySelector(
					'[data-uafrica=icon] .active.' + checkpoint.status
				);
				activeEle.classList.remove( 'hidden' );
				// activeEle.classList.add(checkpoint.status);
			}

			checkpoint.time = new Date( checkpoint.time ).toLocaleString();

			classThis._setValue( checkpointShadowEle, 'time', checkpoint.time );
			classThis._setValue(
				checkpointShadowEle,
				'status',
				checkpoint.status_friendly
			);
			classThis._setValue(
				checkpointShadowEle,
				'message',
				checkpoint.message
			);
			classThis._setValue(
				checkpointShadowEle,
				'location',
				checkpoint.location
			);
			// insert the step in the checkpoint list.
			checkpointsEle.insertBefore( checkpointShadowEle, null );
		} );
	}

	displayError() {
		this.validationEle.classList.remove( 'hidden' );
		this.validationEle.textContent = uafrica_shipping_l10n.not_found.replace(
			'%s',
			this.orderNR
		);
	}

	/**
	 *
	 * @param {Element} parentEle
	 * @param {string }dataAttribute
	 * @param {string} value
	 * @private
	 */
	_setValue( parentEle, dataAttribute, value ) {
		const targetEleS = parentEle.querySelectorAll(
			'[data-uafrica=' + dataAttribute + ']'
		);
		if ( 0 === targetEleS.length ) {
			return; // empty list, no need to loop.
		}

		targetEleS.forEach( function ( targetEle ) {
			targetEle.textContent = value;
		} );
	}
};
// document ready.
document.addEventListener( 'DOMContentLoaded', () => {
	const shippingContainers = document.querySelectorAll(
		'.uafrica-shipping-container'
	);
	if ( null === shippingContainers ) {
		return; // didn't find uAfrica shipping container, no continue;
	}

	shippingContainers.forEach( function ( shippingContainer ) {
		new uAfricaShipping( shippingContainer );
	} );
} );
